@@ -1,6 +1,8 @@
 from collie.model.base import *
+from collie.model.cold_start_matrix_factorization import *
 from collie.model.collaborative_metric_learning import *
 from collie.model.deep_fm import *
+from collie.model.hybrid_matrix_factorization import *
 from collie.model.hybrid_pretrained_matrix_factorization import *
 from collie.model.matrix_factorization import *
 from collie.model.mlp_matrix_factorization import *
